globals [  
   clock      ;; how many simulation step have passed
   grp-data
   dayhabitat
   color-min
   color-max
   clock-max 
   use-file ;; Choose whether to use a data file (1) or use simulated data (0)
   pred-killed ;; amount killed by the predator
   energy-killed ;; amount killed by running out of energy
   average-directed-movement
   total-directed-movement
   pred-killed-at-depth ;; vector describing how many are killed by predation at each depth
   energy-killed-at-depth ;; vector describing how many are killed by energy loss at each depth
  ]

patches-own [
    GRP  ;; habitat quality in patch
    prisk  ;; risk of predation in patch
  ]
   
breed [ fish fishy ]

 fish-own [ 
 PiI   ;; fear of predation (low pii = low fear)
 energy  ;; how much energy the fish has (function of resources gained versus used)
  ]

to make-movie

  ;; prompt user for movie location
  user-message "First, save your new movie file (choose a name ending with .mov)"
  let path user-new-file
  if not is-string? path [ stop ]  ;; stop if user cancelled

  ;; run the model
  setup
  movie-start path
  movie-grab-view
  while [ clock < clock-max ]
    [ go
      movie-grab-view ]

  ;; export the movie
  movie-close
  user-message (word "Exported movie to " path)
end

to setup
  clear-all
  set-default-shape fish "fish"
  create-fish 100 [
    set color orange
    setxy random-xcor (- 1) * (0 + random-float 25) ;; start fish in good GRP area
    ifelse(Pii-is-random)
      [set PiI random-float PiIMax] ;; high piimax is high predator fear
      [set PiI PiIMax]
    set energy (random-float .5) + .5  ;; start with a random amt. of energy 0.5 - 1
    set pred-killed 0
    set energy-killed 0
    set total-directed-movement 0
    set pred-killed-at-depth []
    set energy-killed-at-depth []

  ]
  
  setup-plot
  
  do-plot
   
  set clock 0
  set clock-max 259
  
  ask patches
      [set prisk  max-prisk * (((pycor + 25) / 25) ^ 7 )]
;;;;;;;;;;;;;;;;;;;;GRP FILE SECTION
  ;; load file with habitat information
  set use-file (file-exists? data-file-name)
  ifelse ( use-file)
    [ set grp-data[ ]
      file-open data-file-name ;; grpresized.txt is averaged down to 25 depth, grpresized-1to1.txt is on (-1,1), grpresized0to1.txt is on (0,1)
      while[ not file-at-end? ]
       [set grp-data sentence grp-data (list file-read)        ]
        user-message " GRP file loading complete"
           file-close
        set dayhabitat sublist grp-data 0 ( count patches ) 
    ] 
    [;user-message "There is no file of that name in current directory - using simulated data."
      update-fake-grp ]  

    
;; initially set up GRP
  if (use-file)
  [
  (foreach (sort patches) dayhabitat
  [ask ?1 [ set GRP ?2 ] ] )
  
    ask patches[
  ;; set the color scale in blue from GRP in patch
    if(data-file-name = "grpresized.txt" or data-file-name = "grpresized-2digits.txt")
      [ set pcolor 99 * GRP + 10.8222] ; for original GRP file/truncated GRP file
    if(data-file-name = "grpresized-1to1.txt" or data-file-name = "grpresized-1to1-2digits.txt")
      [ set pcolor 99 * GRP * 0.0255884 + 10.8222]  ;[ set pcolor 8 * ((GRP + 1) / 2) + 10]
    if(data-file-name = "grpresized0to1.txt" or data-file-name = "grpresized0to1-2digits.txt")
      [ set pcolor 99 * (GRP * 0.03343746 - 0.00784906) + 10.8222];[ set pcolor 8 * GRP + 10]
    ]
    ]
    end
    
    
;;;;;;;;;;;;;;;;;;;; END GRP FILE SECTION
 
;;______________________________________________________________________________________________________________
to go
  ifelse (clock < clock-max)
    [
    ifelse (use-file)
      [update-grp]
      [update-fake-grp]
    set average-directed-movement 0
    let numfish count turtles
    move
    ifelse (numfish != 0)
      [set average-directed-movement average-directed-movement / numfish]
      [set average-directed-movement 0]
    set total-directed-movement total-directed-movement + average-directed-movement / 260
    set clock clock + 1
    if not any? turtles
      [ stop ]               
      ]
   [stop]
   do-plot
 end 
to update-grp
  set dayhabitat sublist grp-data (clock * 26 * 7) ((clock + 1) * 26 * 7)
 ( foreach sort patches dayhabitat  [ask ?1 [ set GRP ?2 ] ] )
    ask patches[
  ;; set the color scale in blue from GRP in patch
    if(data-file-name = "grpresized.txt" or data-file-name = "grpresized-2digits.txt")
      [ set pcolor 99 * GRP + 10.8222] ; for original GRP file/truncated GRP file
    if(data-file-name = "grpresized-1to1.txt" or data-file-name = "grpresized-1to1-2digits.txt")
      [ set pcolor 99 * GRP * 0.0255884 + 10.8222] ;[ set pcolor 8 * ((GRP + 1) / 2) + 10]
    if(data-file-name = "grpresized0to1.txt" or data-file-name = "grpresized0to1-2digits.txt") 
      [ set pcolor 99 * (GRP * 0.03343746 - 0.00784906) + 10.8222];[ set pcolor 8 * GRP + 10]
    ]
     
end

to update-fake-grp
  ask patches
  [
  if( sim-function-choice = "original") [
    let py pycor * (8 / 25)
    let time-coord clock * (100 / 100)
    ;; Function approximating GRP data shape (from suitability.m)
    set GRP (exp(-((py -(4 * sin((pi / 4.5) * time-coord) - 5.25)) ^ 6) /(2 *(0.4 + 0.00025 *(time-coord - 50) ) ^ 2))) 
    ]
  if ( sim-function-choice = "happy constant day" )
   [ set GRP 0.7 ]
  if ( sim-function-choice = "bad constant day")
   [ set GRP 0.2 ]
  if ( sim-function-choice = "middle bad" )
    [set GRP .4 * (abs((pycor + 12.5) / 12.5) )]
  if ( sim-function-choice = "middle good" )
    [set GRP (1 - .4 * (abs((pycor + 12.5) / 12.5) ))]
  if ( sim-function-choice = "hypoxic day" )
    [set GRP .4 * (((pycor + 25) / 25) ^ 2 )]
  if ( sim-function-choice = "hypoxic day - extreme" )
    [set GRP .4 * (((pycor + 25) / 25) ^ 5 )]
  ]

  ask patches
   ;;set the color scale in red from GRP in patch
    [ set pcolor (GRP * 8 + 10)]
end

to move
  ask fish
  [ step  ;; random motion
    set energy (1 - 0.1) * energy ;; maybe make daily energy loss dynamic
    if (Pii-is-energy)
      [set PiI energy]
    follow-best
    if ((random-float 100) < prisk ) ;; check if fish survives area predation
    [
    set color red
    set shape "x"
    stamp
    set pred-killed pred-killed + 1  ;; fish dies due to predation
    set pred-killed-at-depth lput ycor pred-killed-at-depth

    die 
    ]
    if(energy < death-threshold)  ;; check if fish has enough energy to live
      [
      set color grey
      set shape "face sad"
      stamp
      set energy-killed energy-killed + 1 ;; fish dies due to lack of energy
      set energy-killed-at-depth lput ycor energy-killed-at-depth

      die
      ]
      
    set energy (energy + (1 - energy) * (GRP * GRP-mult)) ;; how much energy is gained
   ]
end

to follow-best
  ;move-to patch-here  ;; go to patch center
  let mypi PiI
  let my-ycor ycor
  let my-energy energy
  let p max-one-of patches [((1 - mypi) * GRP) - (mypi * prisk)] 
  if [((1 - mypi) * GRP) - (mypi * prisk)] of p > (((1 - mypi) * GRP) - (mypi * prisk)) [  ;; if p is better than current location
      face p
      let vert-displacement abs(([pycor] of p) - ycor)  ;; energy loss depends on vertical displacement alone
      set energy energy * (1 - energy-loss) ^ vert-displacement ;; lose a percentage of energy based on displacement
      set average-directed-movement (average-directed-movement + distance p) ;; for adm plot - uses total distance
      move-to p ] 
      
      ;; prevents all integral coordinates
      set xcor xcor + (random-float 1 - .5)
      let y-rand random-float 1
      ifelse (ycor - y-rand) > -25
      [set ycor ycor - y-rand]
      [set ycor -25]

end

to step   ;random motion
  rt random-float 359 ;; turn in a random direction
  fd random-steps-per-day  ;; go forward a few steps
  if ycor < -25
    [set ycor -25]
end

to do-plot
    set-current-plot "Fish Depth"
    set-current-plot-pen "Average"
    plot ((sum [ycor] of fish)/ (count fish) )
    set-current-plot-pen "Median"
    plot ((median [ycor] of fish) )
;    set-current-plot-pen "Average + SD"
;    plot ((sum [ycor] of fish)/ (count fish) + (standard-deviation[ycor] of fish))
;    set-current-plot-pen "Average - SD"
;    plot ((sum [ycor] of fish)/ (count fish) - (standard-deviation[ycor] of fish))
    
    set-current-plot "Average Daily Movement"
    set-current-plot-pen "Directed"
    plot (average-directed-movement)
    set-current-plot-pen "Random"
    plot (random-steps-per-day)
    
    set-current-plot "Depth"
    set-current-plot-pen "# fish"
    histogram [ycor] of fish    

    set-current-plot "Death vs Depth Predation"
    set-current-plot-pen "Predation"
    histogram pred-killed-at-depth

    set-current-plot "Death vs Depth Energy"
    set-current-plot-pen "Energy"
    histogram energy-killed-at-depth
    
    set-current-plot "Fish Distribution in Water Column"
    set-current-plot-pen "% Deep"
    plot (count fish with [ycor < -17]/ (count fish) )
    set-current-plot-pen "% Middle"
    plot (count fish with [ycor >= -17 AND ycor < -7]/ (count fish) )
    set-current-plot-pen "% Top"
    plot (count fish with [ycor >= -7]/ (count fish) )

end


to setup-plot
  set-current-plot "Fish Depth"
  set-plot-y-range -25 0
  
  set-current-plot "Average Daily Movement"
  
  set-current-plot "Depth"
  set-plot-y-range 0 50
  set-plot-x-range -25 0

  set-current-plot "Death vs Depth Predation"
  set-plot-y-range 0 10
  set-plot-x-range -25 0
  
  set-current-plot "Death vs Depth Energy"
  set-plot-y-range 0 50
  set-plot-x-range -25 0
  
  set-current-plot "Fish Distribution in Water Column"
  set-plot-y-range 0 1

end
@#$#@#$#@
GRAPHICS-WINDOW
791
12
955
615
3
-1
22.0
1
10
1
1
1
0
1
0
1
-3
3
-25
0
0
0
1
ticks

CC-WINDOW
5
721
972
816
Command Center
0

BUTTON
12
10
67
43
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
72
10
127
43
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

MONITOR
721
10
778
55
clock
clock
17
1
11

BUTTON
142
10
239
43
NIL
make-movie
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
8
58
427
279
Fish Depth
Days
Depth
0.0
255.0
0.0
1.0
true
true
PENS
"Average" 1.0 0 -16777216 true
"Median" 1.0 0 -1 true

TEXTBOX
621
520
771
645
A lighter shade of red correspondes to a higher GRP (growth rate potential), i.e. better habitat quality\n\nRED (X) died due to predation.\nGREY (Skull) ran out of energy.
11
0.0
1

SLIDER
21
423
193
456
max-prisk
max-prisk
0
1
0.8
0.05
1
NIL
HORIZONTAL

SLIDER
196
423
368
456
PiIMax
PiIMax
0
1
0
.01
1
NIL
HORIZONTAL

MONITOR
643
10
715
55
Count Fish
count fish
17
1
11

SLIDER
21
459
193
492
GRP-mult
GRP-mult
0
1
0.15
.01
1
NIL
HORIZONTAL

SLIDER
197
459
369
492
energy-loss
energy-loss
0
1
0
.001
1
NIL
HORIZONTAL

SLIDER
791
635
963
668
random-steps-per-day
random-steps-per-day
0
5
0.3
.1
1
NIL
HORIZONTAL

PLOT
18
284
399
404
Average Daily Movement
Days
ADM
0.0
259.0
0.0
5.0
true
true
PENS
"Directed" 1.0 0 -12895429 true
"Random" 1.0 0 -2139308 true

PLOT
577
58
777
208
Depth
Depth
# Fish
-25.0
0.0
0.0
50.0
true
false
PENS
"# fish" 1.0 1 -16777216 true

PLOT
577
210
777
360
Death vs Depth Predation
Depth
# Fish
-25.0
0.0
0.0
10.0
true
false
PENS
"Predation" 1.0 1 -16777216 true

PLOT
579
366
779
516
Death vs Depth Energy
Depth
# Fish
-25.0
0.0
0.0
20.0
true
false
PENS
"Energy" 1.0 1 -16777216 true

MONITOR
244
10
354
55
GRP Loaded %
length grp-data / 473.06\n
2
1
11

CHOOSER
360
10
563
55
data-file-name
data-file-name
"grpresized.txt" "grpresized-2digits.txt" "grpresized0to1.txt" "grpresized0to1-2digits.txt" "grpresized-1to1.txt" "grpresized-1to1-2digits.txt" "Use Simulated GRP Function"
5

PLOT
21
536
406
707
Fish Distribution in Water Column
Time
%
0.0
249.0
0.0
1.0
true
true
PENS
"% Deep" 1.0 0 -15390905 true
"% Middle" 1.0 0 -13345367 true
"% Top" 1.0 0 -8275240 true

SWITCH
371
424
497
457
Pii-is-random
Pii-is-random
0
1
-1000

SWITCH
370
459
494
492
Pii-is-energy
Pii-is-energy
1
1
-1000

SLIDER
21
496
193
529
death-threshold
death-threshold
0
1
0.1
.1
1
NIL
HORIZONTAL

CHOOSER
402
284
575
329
sim-function-choice
sim-function-choice
"original" "happy constant day" "bad constant day" "middle good" "middle bad" "hypoxic day" "hypoxic day - extreme"
3

@#$#@#$#@
WHAT IS IT?
-----------
This project explores a simple ecosystem made up of rabbits, grass, and weeds. The rabbits wander around randomly, and the grass and weeds grow randomly.   When a rabbit bumps into some grass or weeds, it eats the grass and gains energy. If the rabbit gains enough energy, it reproduces. If it doesn't gain enough energy, it dies.

The grass and weeds can be adjusted to grow at different rates and give the rabbits differing amounts of energy.  The model can be used to explore the competitive advantages of these variables.


HOW TO USE IT
-------------
Click the SETUP button to setup the rabbits (red), grass (green), and weeds (violet). Click the GO button to start the simulation.

The NUMBER slider controls the initial number of rabbits. The BIRTH-THRESHOLD slider sets the energy level at which the rabbits reproduce.  The GRASS-GROWTH-RATE slider controls the rate at which the grass grows.  The WEEDS-GROWTH-RATE slider controls the rate at which the weeds grow.

The model's default settings are such that at first the weeds are not present (weeds-grow-rate = 0, weeds-energy = 0).  This is so that you can look at the interaction of just rabbits and grass.  Once you have done this, you can start to add in the effect of weeds.


THINGS TO NOTICE
----------------
Watch the COUNT-RABBITS monitor and the POPULATIONS plot window to see how the rabbit population changes over time. At first, there is not enough grass for the rabbits, and many rabbits die. But that allows the grass to grow more freely, providing an abundance of food for the remaining rabbits. The rabbits gain energy and reproduce. The abundance of rabbits leads to a shortage of grass, and the cycle begins again.

The rabbit population goes through a damped oscillation, eventually stabilizing in a narrow range. The total amount of grass also oscillates, out of phase with the rabbit population.

These dual oscillations are characteristic of predator-prey systems. Such systems are usually described by a set of differential equations known as the Lotka-Volterra equations. NetLogo provides a new way of studying predatory-prey systems and other ecosystems.


THINGS TO TRY
-------------
Leaving other parameters alone, change the grass-grow-rate and let the system stabilize again.  Would you expect that there would now be more grass?  More rabbits?

Change only the birth-threshold of the rabbits.  How does this affect the steady-state levels of rabbits and grass?

With the current settings, the rabbit population goes through a damped oscillation. By changing the parameters, can you create an undamped oscillation? Or an unstable oscillation?

In the current version, each rabbit has the same birth-threshold. What would happen if each rabbit had a different birth-threshold? What if the birth-threshold of each new rabbit was slightly different from the birth-threshold of its parent? How would the values for birth-threshold evolve over time?

Now add weeds by making the sliders WEEDS-GROW-RATE the same as GRASS-GROW-RATE and WEEDS-ENERGY the same as GRASS-ENERGY.  Notice that the amount of grass and weeds is about the same.

Now make grass and weeds grow at different rates.  What happens?

What if the weeds grow at the same rate as grass, but they give less energy to the rabbits when eaten (WEEDS-ENERGY is less than GRASS-ENERGY)?

Think of other ways that two plant species might differ and try them out to see what happens to their relative populations.  For example, what if a weed could grow where there was already grass, but grass couldn't grow where there was a weed?  What if the rabbits preferred the plant that gave them the most energy?

Run the model for a bit, then suddenly change the birth-threshold to zero.  What happens?


NETLOGO FEATURES
----------------
Notice that every black patch has a random chance of growing grass or
weeds each turn, using the rule:

|    if (random-float 1000) < weeds-grow-rate and pcolor = black
|      [ set pcolor violet ]
|    if (random-float 1000) < grass-grow-rate and pcolor = black
|      [ set pcolor green ]


RELATED MODELS
--------------
Look at Wolf Sheep Predation for another interacting ecosystem with different rules.


CREDITS AND REFERENCES
----------------------
To refer to this model in academic publications, please use:  Wilensky, U. (2001).  NetLogo Rabbits Grass Weeds model.  http://ccl.northwestern.edu/netlogo/models/RabbitsGrassWeeds.  Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

In other publications, please use:  Copyright 2001 Uri Wilensky.  All rights reserved.  See http://ccl.northwestern.edu/netlogo/models/RabbitsGrassWeeds for terms of use.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

link
true
0
Line -7500403 true 150 0 150 300

link direction
true
0
Line -7500403 true 150 150 30 225
Line -7500403 true 150 150 270 225

monster
false
0
Polygon -7500403 true true 75 150 90 195 210 195 225 150 255 120 255 45 180 0 120 0 45 45 45 120
Circle -16777216 true false 165 60 60
Circle -16777216 true false 75 60 60
Polygon -7500403 true true 225 150 285 195 285 285 255 300 255 210 180 165
Polygon -7500403 true true 75 150 15 195 15 285 45 300 45 210 120 165
Polygon -7500403 true true 210 210 225 285 195 285 165 165
Polygon -7500403 true true 90 210 75 285 105 285 135 165
Rectangle -7500403 true true 135 165 165 270

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

rabbit
false
0
Circle -7500403 true true 76 150 148
Polygon -7500403 true true 176 164 222 113 238 56 230 0 193 38 176 91
Polygon -7500403 true true 124 164 78 113 62 56 70 0 107 38 124 91

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

@#$#@#$#@
NetLogo 4.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
